@@ -19,7 +19,7 @@ from honeybee.model import Model as HBModel
 from honeybee_radiance.sensorgrid import SensorGrid
 from honeybee_radiance.sensor import Sensor
 from ladybug.color import Color
-from ladybug_geometry.geometry3d.pointvector import Point3D
+from ladybug_geometry.geometry3d import Mesh3D
 
 from .actor import Actor
 from .scene import Scene
@@ -32,6 +32,7 @@ from .vtkjs.helper import convert_directory_to_zip_file, add_data_to_viewer
 from .types import DataSetNames, VTKWriters, JoinedPolyData, ImageTypes
 from .config import DataConfig, Autocalculate, Config
 from .legend_parameter import Text
+from .text_actor import TextActor
 
 
 _COLORSET = {
@@ -63,11 +64,11 @@ def _camera_to_grid_actor(actor: Actor, data_name: str, zoom: int = 2,
 
     Args:
         actor: An Actor object.
-        data_name: name of the data being loaded on the grid. This is 
+        data_name: name of the data being loaded on the grid. This is
             used in naming the image files.
         zoom: The zoom level of the camera. Defaults to 15.
         auto_zoom: A boolean to set the camera to auto zoom. Setting this to True will
-            discard the Zoom level. Set this to False to use the zoom level. Defaults to 
+            discard the Zoom level. Set this to False to use the zoom level. Defaults to
             True.
         camera_offset: The distance between the camera and the sensor grid.
             Defaults to 100.
@@ -243,10 +244,23 @@ class Model(object):
             # if all the grids have the same identifier, merge them into one grid
             if len(ids) == 1:
                 id = self._hb_model.properties.radiance.sensor_grids[0].identifier
-                sensors = [
-                    sensor for grid in self._hb_model.properties.radiance.sensor_grids
-                    for sensor in grid.sensors]
-                sensor_grid = SensorGrid(id, sensors)
+
+                # if it's just one grid, use it
+                if len(self._hb_model.properties.radiance.sensor_grids) == 1:
+                    sensor_grid = self._hb_model.properties.radiance.sensor_grids[0]
+                # if there are more than one grid, merge them first
+                else:
+                    grid_meshes = [grid.mesh for grid in
+                                   self._hb_model.properties.radiance.sensor_grids]
+                    if all(grid_meshes):
+                        mesh = Mesh3D.join_meshes(grid_meshes)
+                        sensor_grid = SensorGrid.from_mesh3d(id, mesh)
+                    else:
+                        sensors = [sensor for grid in
+                                   self._hb_model.properties.radiance.sensor_grids
+                                   for sensor in grid.sensors]
+                        sensor_grid = SensorGrid(id, sensors)
+
                 self._sensor_grids.data.append(
                     convert_sensor_grid(sensor_grid, self._sensor_grids_option)
                 )
@@ -341,7 +355,8 @@ class Model(object):
 
     def to_vtkjs(self, *, folder: str = '.', name: str = None, config: str = None,
                  validation: bool = False,
-                 display_mode: DisplayMode = DisplayMode.Shaded) -> str:
+                 model_display_mode: DisplayMode = DisplayMode.Shaded,
+                 grid_display_mode: DisplayMode = DisplayMode.Shaded) -> str:
         """Write the model to a vtkjs file.
 
         Write your honeybee-vtk model to a vtkjs file that you can open in
@@ -356,17 +371,22 @@ class Model(object):
             config: Path to the config file in JSON format. Defaults to None.
             validation: Boolean to indicate whether to validate the data before loading.
                 Defaults to False.
-            display_mode: Display mode for the model. Defaults to shaded.
+            model_display_mode: Display mode for the model. Defaults to shaded.
+            grid_display_mode: Display mode for the Grids. Defaults to shaded.
 
         Returns:
             A text string representing the file path to the vtkjs file.
         """
-        # update display mode
-        self.update_display_mode(display_mode)
+        scene = Scene()
+        actors = self.actors()
+        scene.add_actors(actors)
+
+        self.update_display_mode(model_display_mode)
+        self.sensor_grids.display_mode = grid_display_mode
 
         # load data if provided
         if config:
-            self.load_config(config, validation=validation)
+            self.load_config(config, scene=scene, validation=validation, legend=True)
 
         # name of the vtkjs file
         file_name = name or 'model'
@@ -416,7 +436,8 @@ class Model(object):
     def to_html(self, *, folder: str = '.', name: str = None, show: bool = False,
                 config: str = None,
                 validation: bool = False,
-                display_mode: DisplayMode = DisplayMode.Shaded) -> str:
+                model_display_mode: DisplayMode = DisplayMode.Shaded,
+                grid_display_mode: DisplayMode = DisplayMode.Shaded) -> str:
         """Write the model to an HTML file.
 
         Write your honeybee-vtk model to an HTML file that you can open in any modern
@@ -430,12 +451,13 @@ class Model(object):
                 default browser. Defaults to False
             config: Path to the config file in JSON format. Defaults to None.
             validation: Boolean to indicate whether to validate the data before loading.
-            display_mode: Display mode for the model. Defaults to shaded.
+            model_display_mode: Display mode for the model. Defaults to shaded.
+            grid_display_mode: Display mode for the Grids. Defaults to shaded.
 
         Returns:
             A text string representing the file path to the HTML file.
         """
-        self.update_display_mode(display_mode)
+        self.update_display_mode(model_display_mode)
         # Name of the html file
         file_name = name or 'model'
         # Set the target folder
@@ -445,7 +467,8 @@ class Model(object):
         # Set temp folder to do the operation
         temp_folder = tempfile.mkdtemp()
         vtkjs_file = self.to_vtkjs(
-            folder=temp_folder, config=config, validation=validation)
+            folder=temp_folder, config=config, validation=validation,
+            model_display_mode=model_display_mode, grid_display_mode=grid_display_mode)
         temp_html_file = add_data_to_viewer(vtkjs_file)
         shutil.copy(temp_html_file, html_file)
         try:
@@ -459,7 +482,8 @@ class Model(object):
     def to_files(self, *, folder: str = '.', name: str = None,
                  writer: VTKWriters = VTKWriters.binary, config: str = None,
                  validation: bool = False,
-                 display_mode: DisplayMode = DisplayMode.Shaded) -> str:
+                 model_display_mode: DisplayMode = DisplayMode.Shaded,
+                 grid_display_mode: DisplayMode = DisplayMode.Shaded) -> str:
         """
         Write a .zip of VTK/VTP files.
 
@@ -472,16 +496,22 @@ class Model(object):
             writer: A VTkWriters object. Default is binary which will write .vtp files.
             config: Path to the config file in JSON format. Defaults to None.
             validation: Boolean to indicate whether to validate the data before loading.
-            display_mode: Display mode for the model. Defaults to shaded.
+            model_display_mode: Display mode for the model. Defaults to shaded.
+            grid_display_mode: Display mode for the Grids. Defaults to shaded.
 
         Returns:
             A text string containing the path to the .zip file with VTK/VTP files.
         """
-        # update display mode
-        self.update_display_mode(display_mode)
+        scene = Scene()
+        actors = self.actors()
+        scene.add_actors(actors)
+
+        self.update_display_mode(model_display_mode)
+        self.sensor_grids.display_mode = grid_display_mode
+
         # load data if provided
         if config:
-            self.load_config(config, validation=validation)
+            self.load_config(config, scene=scene, validation=validation, legend=True)
 
         # Name of the html file
         file_name = name or 'model'
@@ -593,7 +623,8 @@ class Model(object):
                        grid_display_mode: DisplayMode = DisplayMode.SurfaceWithEdges,
                        background_color: Tuple[int, int, int] = None,
                        image_type: ImageTypes = ImageTypes.png,
-                       image_width: int = 0, image_height: int = 0) -> List[str]:
+                       image_width: int = 0, image_height: int = 0,
+                       text_actor: TextActor = None) -> List[str]:
         """Export am image for each grid in the model.
 
         Use the config file to specify which grids with which data to export. For
@@ -612,10 +643,12 @@ class Model(object):
             display_mode: Display mode for the grid. Defaults to surface with edges.
             background_color: Background color of the image. Defaults to white.
             image_type: Image type to be exported. Defaults to png.
-            image_width: Image width in pixels. Defaults to 0. Which will use the 
+            image_width: Image width in pixels. Defaults to 0. Which will use the
                 default radiance view's horizontal angle to derive the width.
             image_height: Image height in pixels. Defaults to 0. Which will use the
                 default radiance view's vertical angle to derive the height.
+            text_actor: A TextActor object that defines the properties of the text to be
+                added to the image. Defaults to None.
 
         Returns:
             Path to the folder where the images are exported for each grid.
@@ -644,9 +677,9 @@ class Model(object):
                                        display_mode=grid_display_mode)
                 dataset.color_by = data.identifier
                 actor = Actor(dataset)
-                scene = Scene(background_color=background_color)
-                scene.add_actors(actor)
-                scene.add_cameras(_camera_to_grid_actor(actor, data.identifier))
+                scene = Scene(background_color=background_color, actors=[actor],
+                              cameras=[_camera_to_grid_actor(actor, data.identifier)],
+                              text_actor=text_actor)
                 legend_range = self._get_legend_range(data)
                 self._load_legend_parameters(data, scene, legend_range)
                 image_paths += scene.export_images(folder=folder,
