@@ -13,6 +13,7 @@ from .camera import Camera
 from .headless import try_headless
 from .legend_parameter import LegendParameter
 from .types import ImageTypes
+from .text_actor import TextActor
 
 
 class Scene:
@@ -29,12 +30,19 @@ class Scene:
     Args:
         background_color: A tuple of three integers that represent RGB values of the
             color that you'd like to set as the background color. Defaults to white.
+        actors: A list of Actor objects to be added to the scene. Defaults to None.
+        cameras: A list of Camera objects to be added to the scene. Defaults to None.
+        text_actor: A TextActor object to be added to the scene. Defaults to None.
     """
 
-    def __init__(self, background_color: Tuple[int, int, int] = None) -> None:
+    def __init__(self, background_color: Tuple[int, int, int] = None,
+                 actors: List[Actor] = None, cameras: List[Camera] = None,
+                 text_actor: TextActor = None) -> None:
+
         self.background_color = background_color
-        self._actors = []
-        self._cameras = []
+        self.actors = actors or []
+        self.cameras = cameras or []
+        self.text_actor = text_actor
         self._assistants = []
 
     @property
@@ -60,11 +68,52 @@ class Scene:
         """Actors in the scene."""
         return self._actors
 
+    @actors.setter
+    def actors(self, val: List[Actor]) -> None:
+        """Set actors for the scene."""
+        if not val:
+            self._actors = []
+        elif _validate_input(val, [Actor]):
+            self._actors = val
+        else:
+            raise ValueError(
+                'A list of Actor objects is expected.'
+                f' Instead got {val}.'
+            )
+
     @property
     def cameras(self) -> List[Camera]:
         """A list of honeybee-vtk cameras setup in the scene."""
         return self._cameras
 
+    @cameras.setter
+    def cameras(self, val: List[Camera]) -> None:
+        """Set cameras for the scene."""
+        if not val:
+            self._cameras = []
+        elif _validate_input(val, [Camera]):
+            self._cameras = val
+        else:
+            raise ValueError(
+                'A list of Camera objects is expected.'
+                f' Instead got {val}.'
+            )
+
+    @property
+    def text_actor(self) -> TextActor:
+        """TextActor object in the scene."""
+        return self._text_actor
+
+    @text_actor.setter
+    def text_actor(self, val: TextActor) -> None:
+        """Set the TextActor object in the scene."""
+        if not val:
+            self._text_actor = None
+        elif not isinstance(val, TextActor):
+            raise ValueError('TextActor object is expected.')
+        else:
+            self._text_actor = val
+
     @property
     def assistants(self) -> List[Assistant]:
         """A list of honeybee-vtk assistants working in the scene."""
@@ -102,7 +151,7 @@ class Scene:
             val: Either a list of Camera objects or a single Camera object.
         """
         if isinstance(val, list) and _validate_input(val, [Camera]):
-            self._cameras.extend(val)
+            self._cameras += val
         elif isinstance(val, Camera):
             self._cameras.append(val)
         else:
@@ -127,6 +176,11 @@ class Scene:
                 f' Instead got {val}.'
             )
 
+    def add_text_actor(self, val: TextActor) -> None:
+        """Add a TextActor object to the scene."""
+        assert isinstance(val, TextActor), 'TextActor object is expected.'
+        self._text_actor = val
+
     def update_scene(self) -> None:
         """Update the scene.
 
@@ -143,7 +197,8 @@ class Scene:
 
             self._assistants = [
                 Assistant(background_color=self._background_color, camera=camera,
-                          actors=self._actors, legend_parameters=visible_legend_params)
+                          actors=self._actors, legend_parameters=visible_legend_params,
+                          text_actor=self._text_actor)
                 for camera in self._cameras]
         else:
             raise ValueError(
