@@ -438,11 +438,12 @@ class ModelDataSet:
     representation.
     """
 
-    def __init__(self, name, data: List[PolyData] = None, color: Color = None) -> None:
+    def __init__(self, name, data: List[PolyData] = None, color: Color = None,
+                 display_mode: DisplayMode = DisplayMode.Shaded) -> None:
         self.name = name
         self.data = data or []
         self.color = color
-        self.display_mode = DisplayMode.Shaded
+        self.display_mode = display_mode
         self.color_by = None
 
     @ property
@@ -558,7 +559,7 @@ class ModelDataSet:
         return self._display_mode
 
     @ display_mode.setter
-    def display_mode(self, mode: DisplayMode = DisplayMode.Surface):
+    def display_mode(self, mode: DisplayMode):
         self._display_mode = mode
 
     @ property
